# A Pyhton Implemetation of Lox

This is a python implemetation of a experimental programming language Lox.
Lox is a programming designed by Nystrom Bob, Thanks for his project [Crafting Interpreters](http://craftinginterpreters.com/)

For some reason, the project is not full implemetation of lox features.

## Features

The interpreter support:
- atoms
    - str
    - bool
    - number
- express
    - variable and assign
    - arithmetic and logical
- statment
    - print
    - if
    - for and while loop
    - lexical scopes
    - function
    - class
    - clourse

## Usage

1. Use `pip install loxpy` to install.
2. Use `loxpy` in termianl to run.

## Grammer

Visit [Lox grammer](http://craftinginterpreters.com/appendix-i.html) for more infomation.